@@ -174,6 +174,15 @@ save_session(GnomeClient * client,
   return TRUE;
 }
 
+static void
+monitor_callback(GnomeVFSMonitorHandle *handle,
+                 const gchar *monitor_uri,
+                 const gchar *info_uri,
+                 GnomeVFSMonitorEventType event_type,
+                 gpointer user_data) {
+  g_message("File %s changed.", info_uri);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -228,15 +237,17 @@ main(int argc, char **argv)
   g_value_unset(&value);
 
   error = NULL;
-  if(gconf_init(argc, argv, &error) == FALSE) {
+  if(!gconf_init(argc, argv, &error)) {
     g_assert(error != NULL);
-    g_message("GConf init failed: %s", error->message);
+    g_message(_("Failed to initialize GConf subsystem: %s"), error->message);
     g_error_free(error);
     exit(EXIT_FAILURE);
   }
 
-  if(bonobo_ui_init("Gnome Ghostview", VERSION, &argc, argv) == FALSE)
-    g_error(_("Could not initialize Bonobo!\n"));
+  if(bonobo_ui_init("Gnome Ghostview", VERSION, &argc, argv) == FALSE) {
+    g_message(_("Failed to initialize Bonobo!\n"));
+    exit(EXIT_FAILURE);
+  }
 
   client = gnome_master_client();
 
